==> com.liferay.headless.commerce.admin.catalog.impl-4.0.88-sources.jar: com/liferay/headless/commerce/admin/catalog/internal/jaxrs/exception/mapper/SkuExpirationDateExceptionMapper.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.headless.commerce.admin.catalog.internal.jaxrs.exception.mapper;

import com.liferay.commerce.product.exception.CPInstanceExpirationDateException;
import com.liferay.portal.vulcan.jaxrs.exception.mapper.BaseExceptionMapper;
import com.liferay.portal.vulcan.jaxrs.exception.mapper.Problem;

import javax.ws.rs.core.Response;
import javax.ws.rs.ext.ExceptionMapper;
import javax.ws.rs.ext.Provider;

import org.osgi.service.component.annotations.Component;

/**
 * @author Alessio Antonio Rendina
 * @author Zoltán Takács
 */
@Component(
	property = {
		"osgi.jaxrs.application.select=(osgi.jaxrs.name=Liferay.Headless.Commerce.Admin.Catalog)",
		"osgi.jaxrs.extension=true",
		"osgi.jaxrs.name=Liferay.Headless.Commerce.Admin.Catalog.SkuExpirationDateExceptionMapper"
	},
	service = ExceptionMapper.class
)
@Provider
public class SkuExpirationDateExceptionMapper
	extends BaseExceptionMapper<CPInstanceExpirationDateException> {

	@Override
	protected Problem getProblem(
		CPInstanceExpirationDateException cpInstanceExpirationDateException) {

		return new Problem(
			Response.Status.BAD_REQUEST,
			cpInstanceExpirationDateException.getMessage());
	}

}

==> com.liferay.headless.commerce.admin.catalog.impl-4.0.100-sources.jar: com/liferay/headless/commerce/admin/catalog/internal/jaxrs/exception/mapper/SkuExpirationDateExceptionMapper.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.headless.commerce.admin.catalog.internal.jaxrs.exception.mapper;

import com.liferay.commerce.product.exception.CPInstanceExpirationDateException;
import com.liferay.portal.vulcan.jaxrs.exception.mapper.BaseExceptionMapper;
import com.liferay.portal.vulcan.jaxrs.exception.mapper.Problem;

import javax.ws.rs.ext.ExceptionMapper;
import javax.ws.rs.ext.Provider;

import org.osgi.service.component.annotations.Component;

/**
 * @author Alessio Antonio Rendina
 * @author Zoltán Takács
 */
@Component(
	property = {
		"osgi.jaxrs.application.select=(osgi.jaxrs.name=Liferay.Headless.Commerce.Admin.Catalog)",
		"osgi.jaxrs.extension=true",
		"osgi.jaxrs.name=Liferay.Headless.Commerce.Admin.Catalog.SkuExpirationDateExceptionMapper"
	},
	service = ExceptionMapper.class
)
@Provider
public class SkuExpirationDateExceptionMapper
	extends BaseExceptionMapper<CPInstanceExpirationDateException> {

	@Override
	protected Problem getProblem(
		CPInstanceExpirationDateException cpInstanceExpirationDateException) {

		return new Problem(cpInstanceExpirationDateException);
	}

}
